@@ -1,14 +1,12 @@
 package Form::Tiny::Hook;
-$Form::Tiny::Hook::VERSION = '2.13_1'; # TRIAL
-$Form::Tiny::Hook::VERSION = '2.131';
+$Form::Tiny::Hook::VERSION = '2.13_2'; # TRIAL
+$Form::Tiny::Hook::VERSION = '2.132';
 use v5.10;
 use strict;
 use warnings;
 use Moo;
 use Types::Standard qw(Enum CodeRef Bool);
 
-use namespace::clean;
-
 use constant {
 	HOOK_REFORMAT => 'reformat',
 	HOOK_BEFORE_MANGLE => 'before_mangle',
@@ -71,7 +69,7 @@ Form::Tiny::Hook - a representation of a hook
 
 	# in your form class
 
-	# the following will be coerced into Form::Tiny::Filter
+	# the following will be coerced into Form::Tiny::Hook
 	form_hook before_validation => $coderef;
 
 =head1 DESCRIPTION
