@@ -1,6 +1,6 @@
 package Form::Tiny::Inline;
-$Form::Tiny::Inline::VERSION = '2.13_1'; # TRIAL
-$Form::Tiny::Inline::VERSION = '2.131';
+$Form::Tiny::Inline::VERSION = '2.13_2'; # TRIAL
+$Form::Tiny::Inline::VERSION = '2.132';
 use v5.10;
 use strict;
 use warnings;
@@ -22,8 +22,8 @@ sub new
 # actual inline form package
 {
 	package Form::Tiny::Inline::Form;
-$Form::Tiny::Inline::Form::VERSION = '2.13_1'; # TRIAL
-$Form::Tiny::Inline::Form::VERSION = '2.131';
+$Form::Tiny::Inline::Form::VERSION = '2.13_2'; # TRIAL
+$Form::Tiny::Inline::Form::VERSION = '2.132';
 use v5.10;
 	use strict;
 	use warnings;
@@ -64,8 +64,8 @@ use v5.10;
 # builder package to allow adding meta roles with no package magic
 {
 	package Form::Tiny::Inline::Builder;
-$Form::Tiny::Inline::Builder::VERSION = '2.13_1'; # TRIAL
-$Form::Tiny::Inline::Builder::VERSION = '2.131';
+$Form::Tiny::Inline::Builder::VERSION = '2.13_2'; # TRIAL
+$Form::Tiny::Inline::Builder::VERSION = '2.132';
 use v5.10;
 	use strict;
 	use warnings;
@@ -87,6 +87,15 @@ use v5.10;
 		$meta->set_form_roles($wanted->{roles});
 		$meta->bootstrap;
 
+		if ($args{fields}) {
+			for my $field_name (keys %{$args{fields}}) {
+				$meta->add_field({
+					name => $field_name,
+					%{$args{fields}{$field_name}},
+				});
+			}
+		}
+
 		for my $field (@{$args{field_defs} // []}) {
 			$meta->add_field($field);
 		}
