@@ -1,6 +1,6 @@
 package Form::Tiny::Meta;
-$Form::Tiny::Meta::VERSION = '2.13_1'; # TRIAL
-$Form::Tiny::Meta::VERSION = '2.131';
+$Form::Tiny::Meta::VERSION = '2.13_2'; # TRIAL
+$Form::Tiny::Meta::VERSION = '2.132';
 use v5.10;
 use strict;
 use warnings;
@@ -16,8 +16,6 @@ use Form::Tiny::Error;
 use Form::Tiny::Utils qw(try uniq get_package_form_meta has_form_meta);
 require Moo::Role;
 
-use namespace::clean;
-
 # more clear error messages in some crucial cases
 our @CARP_NOT = qw(Form::Tiny Form::Tiny::Form);
 
@@ -351,9 +349,24 @@ sub inherit_from
 
 sub _build_blueprint
 {
-	my ($self, $context) = @_;
+	my ($self, $context, %params) = @_;
 	my %result;
 
+	my $recurse = $params{recurse} // 1;
+	my $transform_base = sub {
+		my ($def) = @_;
+
+		if ($def->is_subform && $recurse) {
+			my $meta = get_package_form_meta(ref $def->type);
+			return $meta->blueprint($def->type, %params);
+		}
+
+		return $def;
+	};
+
+	my $transform = $params{transform} // $transform_base;
+
+
 	# croak, since we don't know anything about dynamic fields in static context
 	croak "Can't create a blueprint of a dynamic form"
 		if $self->is_dynamic && !$context;
@@ -363,12 +376,6 @@ sub _build_blueprint
 	my $fields = $context ? $context->field_defs : $self->fields;
 
 	for my $def (@$fields) {
-		my $value = $def;
-		if ($def->is_subform) {
-			my $meta = get_package_form_meta(ref $def->type);
-			$value = $meta->blueprint($def->type);
-		}
-
 		my @meta = @{$def->get_name_path->meta};
 		my @path = @{$def->get_name_path->path};
 
@@ -380,7 +387,7 @@ sub _build_blueprint
 			$def, [
 				{
 					path => \@path,
-					value => $value
+					value => scalar $transform->($def, $transform_base),
 				}
 			]
 		);
@@ -391,10 +398,13 @@ sub _build_blueprint
 
 sub blueprint
 {
-	my ($self, $context) = @_;
+	my ($self, @args) = @_;
+	my $context;
+	$context = shift @args
+		if @args && has_form_meta($args[0]);
 
-	if ($self->is_dynamic) {
-		return $self->_build_blueprint($context);
+	if ($self->is_dynamic || @args) {
+		return $self->_build_blueprint($context, @args);
 	}
 	else {
 		# $context can be skipped if the form is not dynamic
